@@ -1,8 +1,7 @@
 # 2016. 1. 10 by Hans Roh hansroh@gmail.com
 
-__version__ = "0.2.13.65"
+__version__ = "0.2.13.69"
 version_info = tuple (map (lambda x: not x.isdigit () and x or int (x),  __version__.split (".")))
-
 from multiprocessing import Pool
 from tqdm import tqdm as tqdm_
 import concurrent.futures
@@ -12,6 +11,7 @@ from .termcolor import tc
 import subprocess as subprocess_
 import asyncio as asyncio_
 from asyncio.tasks import Task
+from loky import get_reusable_executor
 import sys
 if sys.version_info >= (3, 5):
     from .aio import aio
@@ -34,7 +34,8 @@ def tpool (workers = 1):
 threading = tpool
 
 def ppool (workers = 1):
-    return concurrent.futures.ProcessPoolExecutor (max_workers = workers)
+    # return concurrent.futures.ProcessPoolExecutor (max_workers = workers)
+    return get_reusable_executor (max_workers = workers)
 processing = ppool
 
 def ppool2 (workers = 1):
