@@ -6,6 +6,7 @@ import math
 helps = []
 long_opts = ['help']
 short_opts = []
+aliases = {}
 
 def usage (exit = False):
     maxlen = max ([len (opt) + 2 for opt, desc in helps]) + 1
@@ -21,31 +22,34 @@ def usage (exit = False):
     exit and sys.exit ()
 
 def add_option (sname = None, lname = None, desc = None):
-    global long_opts, short_opts
+    global long_opts, short_opts, aliases
 
-    val = None
+    sval, lval = None, None
     if lname:
         if lname.startswith ("--"):
             lname = lname [2:]
-        try: lname, val = lname.split ("=", 1)
+        try: lname, lval = lname.split ("=", 1)
         except ValueError: pass
         assert lname not in long_opts, "option --" + lname + ' is already exist'
-        long_opts.append (lname + (val and "=" or ''))
+        long_opts.append (lname + (lval is not None and "=" or ''))
 
     if sname:
         if sname.startswith ("-"):
             sname = sname [1:]
         try:
-            sanme, val_ = sname.split ("=", 1)
+            sname, sval = sname.split ("=", 1)
         except ValueError:
             pass
-        else:
-            if val_ and not val:
-                val = val_
         assert sname not in short_opts, "option -" + sname + ' is already exist'
-        short_opts.append (sname + (val and ":" or ''))
+        short_opts.append (sname + (sval is not None and ":" or ''))
 
+    if (sname and lname) and (sval is None and lval is not None) or (lval is None and sval is not None):
+        raise SystemError ('-{} and --{} spec not matched'.format (sname, lname))
+
+    val = sval or lval
     if lname and sname:
+        aliases ['--' + lname] = '-' + sname
+        aliases ['-' + sname] = '--' + lname
         opt = "-{}, --{}".format (sname, lname)
     elif sname:
         opt = '-{}'.format (sname)
@@ -71,19 +75,22 @@ class ArgumentOptions:
     def __str__ (self):
         return str (list (self.items ()))
 
-    def items (self):
-        return self.__kopt.items ()
-
     def __contains__ (self, k):
         return k in self.__kopt
 
-    def get (self, k, v = None):
-        return self.__kopt.get (k, v)
+    def items (self):
+        return self.__kopt.items ()
 
-    def any (self, *ks):
-        for k in ks:
-            if k in self.__kopt:
-                return self.__kopt [k]
+    def get (self, k, v = None):
+        global aliases
+
+        try: val = self.__kopt [k]
+        except KeyError:
+            if k in aliases:
+                k2 = aliases [k]
+                return self.__kopt.get (k2, v)
+            return v
+        return val
 
     def set (self, k, v = None):
         self.__kopt [k] = v
@@ -94,9 +101,8 @@ class ArgumentOptions:
         except KeyError:
             pass
 
-def options ():
+def collect ():
     global long_opts, short_opts
-
     argopt = optparse.getopt (sys.argv [1:], "".join (short_opts).replace ("=", ":"), long_opts)
     kopts_ = {}
     for k, v in argopt [0]:
@@ -107,5 +113,4 @@ def options ():
         else:
             kopts_ [k] = v
     return ArgumentOptions (kopts_, argopt [1])
-
-collect = options
+options = collect
