@@ -127,7 +127,7 @@ def poll(timeout=0.0, map=None):
         map = socket_map
     if map:
         r = []; w = []; e = []
-        for idx, (fd, obj) in enumerate (list(map.items())):
+        for fd, obj in map.items():
             is_r = obj.readable()
             is_w = obj.writable()
             if is_r:
@@ -162,6 +162,35 @@ def poll(timeout=0.0, map=None):
                 continue
             _exception(obj)
 
+def _poll_map (map, pollster, timeout):
+    for fd, obj in map.items():
+        flags = 0
+        if obj.readable():
+            flags |= select.POLLIN | select.POLLPRI
+        if obj.writable() and not obj.accepting:
+            flags |= select.POLLOUT
+        if flags:
+            flags |= select.POLLERR | select.POLLHUP | select.POLLNVAL
+            try:
+                pollster.register(fd, flags)
+            except:
+                # add by Hans Roh on Jun 2, 2020
+                obj.handle_error ()
+                continue
+
+    try:
+        r = pollster.poll(timeout)
+    except select.error as err:
+        if err.args[0] != EINTR:
+            raise
+        r = []
+
+    for fd, flags in r:
+        obj = map.get(fd)
+        if obj is None:
+            continue
+        readwrite(obj, flags)
+
 def poll2(timeout=0.0, map=None):
     # Use the poll() support added to the select module in Python 2.0
     if map is None:
@@ -169,53 +198,12 @@ def poll2(timeout=0.0, map=None):
     if timeout is not None:
         # timeout is in milliseconds
         timeout = int(timeout*1000)
-    pollster = select.poll()
-    if map:
-        for fd, obj in list(map.items()):
-            flags = 0
-            if obj.readable():
-                flags |= select.POLLIN | select.POLLPRI
-            # accepting sockets should not be writable
-            if obj.writable() and not obj.accepting:
-                flags |= select.POLLOUT
-            if flags:
-                pollster.register(fd, flags)
-
-        r = pollster.poll(timeout)
-        for fd, flags in r:
-            obj = map.get(fd)
-            if obj is None:
-                continue
-            readwrite(obj, flags)
+    map and _poll_map (map, select.poll(), timeout)
 
 def epoll(timeout=0.0, map=None):
     if map is None:
         map = socket_map
-    pollster = select.epoll()
-    if map:
-        for fd, obj in list(map.items()):
-            flags = 0
-            if obj.readable():
-                flags |= select.POLLIN | select.POLLPRI
-            if obj.writable() and not obj.accepting:
-                flags |= select.POLLOUT
-            if flags:
-                # Only check for exceptions if object was either readable or writable
-                flags |= select.POLLERR | select.POLLHUP | select.POLLNVAL
-                pollster.register(fd, flags)
-
-        try:
-            r = pollster.poll(timeout)
-        except select.error as err:
-            if err.args[0] != EINTR:
-                raise
-            r = []
-
-        for fd, flags in r:
-            obj = map.get(fd)
-            if obj is None:
-                continue
-            readwrite(obj, flags)
+    map and _poll_map (map, select.epoll(), timeout)
 
 def kqueue(timeout=0.0, map=None):
     if map is None:
@@ -613,7 +601,7 @@ def compact_traceback():
 def close_all(map=None, ignore_all=False):
     if map is None:
         map = socket_map
-    for x in list(map.values()):
+    for x in map.values():
         try:
             x.close()
         except OSError as x:
